==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/IssuerAlternativeNames.h <==
// public class gnu.java.security.x509.ext.IssuerAlternativeNames

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class f5a646eb7643cabf gnu_java_security_x509_ext_IssuerAlternativeNames
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_IssuerAlternativeNames_H_
#define _JC_gnu_java_security_x509_ext_IssuerAlternativeNames_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_gnu_java_security_x509_ext_GeneralNames$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_refs	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_nonrefs	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$refs	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$refs;
typedef struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$nonrefs	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object;

typedef struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$fields_struct	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vmethods	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtable	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtype	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24IssuerAlternativeNames;
};
extern _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$fields_struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object *, struct _jc_byte_array *);

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method$getNames$d565a0d1c278ffb5(_jc_env *, struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method_info$getNames$d565a0d1c278ffb5;
extern _jc_method _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vmethods {
	struct _jc_object	*(*getNames$d565a0d1c278ffb5)(_jc_env *, struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vmethods	gnu_java_security_x509_ext_IssuerAlternativeNames;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_refs {
	struct _jc_gnu_java_security_x509_ext_GeneralNames$object	*names;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$refs {
    _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_refs	gnu_java_security_x509_ext_IssuerAlternativeNames;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_nonrefs	gnu_java_security_x509_ext_IssuerAlternativeNames;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object {
	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtype _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_IssuerAlternativeNames, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_IssuerAlternativeNames_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/IssuerAlternativeNames.h <==
// public class gnu.java.security.x509.ext.IssuerAlternativeNames

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 71d2e43dc7382815 gnu_java_security_x509_ext_IssuerAlternativeNames
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_IssuerAlternativeNames_H_
#define _JC_gnu_java_security_x509_ext_IssuerAlternativeNames_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_gnu_java_security_x509_ext_GeneralNames$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_refs	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_nonrefs	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$refs	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$refs;
typedef struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$nonrefs	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object;

typedef struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$fields_struct	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vmethods	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtable	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtype	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24IssuerAlternativeNames;
};
extern _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$fields_struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method$getNames$d565a0d1c278ffb5(_jc_env *, struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method_info$getNames$d565a0d1c278ffb5;
extern _jc_method _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vmethods {
	struct _jc_object	*(*getNames$d565a0d1c278ffb5)(_jc_env *, struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vmethods	gnu_java_security_x509_ext_IssuerAlternativeNames;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_refs {
	struct _jc_gnu_java_security_x509_ext_GeneralNames$object	*names;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$refs {
    _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_refs	gnu_java_security_x509_ext_IssuerAlternativeNames;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$sub_nonrefs	gnu_java_security_x509_ext_IssuerAlternativeNames;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$object {
	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_IssuerAlternativeNames$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$vtype _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_IssuerAlternativeNames, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_IssuerAlternativeNames$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_IssuerAlternativeNames_H_ */
